@@ -58,6 +58,16 @@ shared_examples_for "a parser" do |parser|
         end
       end
 
+      context "element with the same inner element and attribute name" do
+        before do
+          @xml = "<user name='John'><name>Smith</name></user>"
+        end
+
+        it "returns nams as Array" do
+          expect(MultiXml.parse(@xml)['user']['name']).to eq ['John', 'Smith']
+        end
+      end
+
       context "with content" do
         before do
           @xml = '<user>Erik Michaels-Ober</user>'
@@ -122,63 +132,11 @@ shared_examples_for "a parser" do |parser|
 
       context "with :symbolize_keys => true" do
         before do
-          @xml = '<user><name>Erik Michaels-Ober</name></user>'
+          @xml = '<users><user name="Erik Michaels-Ober"/><user><name>Wynn Netherland</name></user></users>'
         end
 
         it "symbolizes keys" do
-          expect(MultiXml.parse(@xml, :symbolize_keys => true)).to eq({:user => {:name => "Erik Michaels-Ober"}})
-        end
-      end
-
-      context "when value is true" do
-        before do
-          pending
-          @xml = '<tag>true</tag>'
-        end
-
-        it "returns true" do
-          expect(MultiXml.parse(@xml)['tag']).to be_true
-        end
-      end
-
-      context "when value is false" do
-        before do
-          pending
-          @xml = '<tag>false</tag>'
-        end
-
-        it "returns false" do
-          expect(MultiXml.parse(@xml)['tag']).to be_false
-        end
-      end
-
-      context "when key is id" do
-        before do
-          pending
-          @xml = '<id>1</id>'
-        end
-
-        it "returns a Fixnum" do
-          expect(MultiXml.parse(@xml)['id']).to be_a(Fixnum)
-        end
-
-        it "returns the correct number" do
-          expect(MultiXml.parse(@xml)['id']).to eq(1)
-        end
-      end
-
-      context "when key contains _id" do
-        before do
-          pending
-          @xml = '<tag_id>1</tag_id>'
-        end
-
-        it "returns a Fixnum" do
-          expect(MultiXml.parse(@xml)['tag_id']).to be_a(Fixnum)
-        end
-
-        it "returns the correct number" do
-          expect(MultiXml.parse(@xml)['tag_id']).to eq(1)
+          expect(MultiXml.parse(@xml, :symbolize_keys => true)).to eq({:users => {:user => [{:name => "Erik Michaels-Ober"}, {:name => "Wynn Netherland"}]}})
         end
       end
 
